
using System;
using System.Security;
using System.Security.Permissions;


[Serializable,
 AttributeUsage(AttributeTargets.Method |
                AttributeTargets.Constructor |
                AttributeTargets.Class |
                AttributeTargets.Struct |
                AttributeTargets.Assembly,
                AllowMultiple = true,
                Inherited = false)]
sealed public class ToasterPermissionAttribute : CodeAccessSecurityAttribute
{
    // State fields to mirror those in actual permission.
    public bool ExclusiveAccess;
    public bool Information;
    public bool Eject;
    public ToastLevel ToastLevel;

    // Nothing to do in constructor but pass action code back up to
    // the base implementation.
    public ToasterPermissionAttribute(SecurityAction action)
        : base(action)
    {
    }

    // Create a permission instance with the current state set in the
    // attribute.
    public override IPermission CreatePermission()
    {
        ToasterPermission perm;

        // The runtime automatically provides a property which
        // indicates whether an unrestricted instance is required.
        if (Unrestricted)
            return new ToasterPermission(PermissionState.Unrestricted);

        // Create an instance with default (empty) state.
        perm = new ToasterPermission(PermissionState.None);

        // Copy state across.
        perm.ExclusiveAccess = ExclusiveAccess;
        perm.Information = Information;
        perm.Eject = Eject;
        perm.ToastLevel = ToastLevel;

        // Return the finished permission.
        return perm;
    }
}

